@@ -1,4 +1,5 @@
-use criterion::black_box;
+use std::hint::black_box;
+
 use criterion::criterion_group;
 use criterion::criterion_main;
 use criterion::Criterion;
