@@ -26,6 +26,12 @@ pub enum ComparisonOperator {
     NullSafeEqual,
 }
 
+#[derive(Clone, PartialEq)]
+pub enum GroupComparisonOperator {
+    All,
+    Any,
+}
+
 #[derive(Clone, PartialEq)]
 pub enum BinaryLogicalOperator {
     Or,
