@@ -6,7 +6,6 @@ use dyn_clone::DynClone;
 use crate::expression::Expr;
 
 pub enum StatementKind {
-    Do,
     Select,
     Where,
     Having,
@@ -16,7 +15,7 @@ pub enum StatementKind {
     GroupBy,
     AggregateFunction,
     WindowFunction,
-    GlobalVariable,
+    Qualify,
     Into,
 }
 
@@ -27,37 +26,6 @@ pub trait Statement: DynClone {
     fn as_any(&self) -> &dyn Any;
 }
 
-pub enum Query {
-    Do(DoStatement),
-    Select(GQLQuery),
-    GlobalVariableDeclaration(GlobalVariableStatement),
-    Describe(DescribeStatement),
-    ShowTables,
-}
-
-pub struct GQLQuery {
-    pub statements: HashMap<&'static str, Box<dyn Statement>>,
-    pub alias_table: HashMap<String, String>,
-    pub has_aggregation_function: bool,
-    pub has_group_by_statement: bool,
-    pub hidden_selections: HashMap<String, Vec<String>>,
-}
-
-#[derive(Clone)]
-pub struct DoStatement {
-    pub expression: Box<dyn Expr>,
-}
-
-impl Statement for DoStatement {
-    fn as_any(&self) -> &dyn Any {
-        self
-    }
-
-    fn kind(&self) -> StatementKind {
-        StatementKind::Do
-    }
-}
-
 #[derive(Clone)]
 pub enum Distinct {
     None,
@@ -161,7 +129,7 @@ impl Statement for LimitStatement {
 
 #[derive(Clone)]
 pub struct OffsetStatement {
-    pub count: usize,
+    pub start: Box<dyn Expr>,
 }
 
 impl Statement for OffsetStatement {
@@ -271,6 +239,21 @@ impl Statement for WindowFunctionsStatement {
     }
 }
 
+#[derive(Clone)]
+pub struct QualifyStatement {
+    pub condition: Box<dyn Expr>,
+}
+
+impl Statement for QualifyStatement {
+    fn as_any(&self) -> &dyn Any {
+        self
+    }
+
+    fn kind(&self) -> StatementKind {
+        StatementKind::Where
+    }
+}
+
 #[derive(Clone)]
 pub enum AggregateValue {
     Expression(Box<dyn Expr>),
@@ -292,22 +275,6 @@ impl Statement for AggregationsStatement {
     }
 }
 
-#[derive(Clone)]
-pub struct GlobalVariableStatement {
-    pub name: String,
-    pub value: Box<dyn Expr>,
-}
-
-impl Statement for GlobalVariableStatement {
-    fn as_any(&self) -> &dyn Any {
-        self
-    }
-
-    fn kind(&self) -> StatementKind {
-        StatementKind::GlobalVariable
-    }
-}
-
 #[derive(Clone)]
 pub struct IntoStatement {
     pub file_path: String,
@@ -325,8 +292,3 @@ impl Statement for IntoStatement {
         StatementKind::Into
     }
 }
-
-#[derive(Debug)]
-pub struct DescribeStatement {
-    pub table_name: String,
-}
