@@ -1,6 +1,8 @@
 use std::any::Any;
 
-use crate::types::{boolean::BoolType, float::FloatType};
+use crate::types::array::ArrayType;
+use crate::types::boolean::BoolType;
+use crate::types::float::FloatType;
 
 use super::base::DataType;
 
@@ -112,26 +114,50 @@ impl DataType for IntType {
         vec![Box::new(IntType)]
     }
 
+    fn can_perform_group_eq_op_with(&self) -> Vec<Box<dyn DataType>> {
+        vec![Box::new(ArrayType::new(Box::new(IntType)))]
+    }
+
     fn can_perform_bang_eq_op_with(&self) -> Vec<Box<dyn DataType>> {
         vec![Box::new(IntType)]
     }
 
+    fn can_perform_group_bang_eq_op_with(&self) -> Vec<Box<dyn DataType>> {
+        vec![Box::new(ArrayType::new(Box::new(IntType)))]
+    }
+
     fn can_perform_gt_op_with(&self) -> Vec<Box<dyn DataType>> {
         vec![Box::new(IntType)]
     }
 
+    fn can_perform_group_gt_op_with(&self) -> Vec<Box<dyn DataType>> {
+        vec![Box::new(ArrayType::new(Box::new(IntType)))]
+    }
+
     fn can_perform_gte_op_with(&self) -> Vec<Box<dyn DataType>> {
         vec![Box::new(IntType)]
     }
 
+    fn can_perform_group_gte_op_with(&self) -> Vec<Box<dyn DataType>> {
+        vec![Box::new(ArrayType::new(Box::new(IntType)))]
+    }
+
     fn can_perform_lt_op_with(&self) -> Vec<Box<dyn DataType>> {
         vec![Box::new(IntType)]
     }
 
+    fn can_perform_group_lt_op_with(&self) -> Vec<Box<dyn DataType>> {
+        vec![Box::new(ArrayType::new(Box::new(IntType)))]
+    }
+
     fn can_perform_lte_op_with(&self) -> Vec<Box<dyn DataType>> {
         vec![Box::new(IntType)]
     }
 
+    fn can_perform_group_lte_op_with(&self) -> Vec<Box<dyn DataType>> {
+        vec![Box::new(ArrayType::new(Box::new(IntType)))]
+    }
+
     fn can_perform_neg_op(&self) -> bool {
         true
     }
