@@ -1,8 +1,8 @@
 use std::any::Any;
 use std::cmp::Ordering;
 
-use gitql_ast::types::base::DataType;
 use gitql_ast::types::null::NullType;
+use gitql_ast::types::DataType;
 
 use super::base::Value;
 
