@@ -1,12 +1,12 @@
 use std::collections::HashMap;
 use std::vec;
 
-use gitql_ast::statement::DescribeStatement;
+use gitql_ast::query::DescribeQuery;
+use gitql_ast::query::DoQuery;
+use gitql_ast::query::GlobalVariableDeclQuery;
+use gitql_ast::query::Query;
+use gitql_ast::query::SelectQuery;
 use gitql_ast::statement::Distinct;
-use gitql_ast::statement::DoStatement;
-use gitql_ast::statement::GQLQuery;
-use gitql_ast::statement::GlobalVariableStatement;
-use gitql_ast::statement::Query;
 use gitql_ast::statement::SelectStatement;
 use gitql_core::environment::Environment;
 use gitql_core::object::GitQLObject;
@@ -18,11 +18,10 @@ use gitql_core::values::Value;
 use crate::data_provider::DataProvider;
 use crate::engine_distinct::apply_distinct_operator;
 use crate::engine_evaluator::evaluate_expression;
-use crate::engine_executor::execute_global_variable_statement;
 use crate::engine_executor::execute_statement;
 
-/// Static Logical Plan, later must be replaced by optimized and Logical Planner
-const FIXED_LOGICAL_PLAN_LEN: usize = 9;
+/// Static Logical Plan, later must be replaced by a Plan from the Logical query Planner
+const FIXED_LOGICAL_PLAN_LEN: usize = 10;
 const FIXED_LOGICAL_PLAN: [&str; FIXED_LOGICAL_PLAN_LEN] = [
     "select",
     "where",
@@ -30,13 +29,14 @@ const FIXED_LOGICAL_PLAN: [&str; FIXED_LOGICAL_PLAN_LEN] = [
     "aggregation",
     "having",
     "window_functions",
+    "qualify",
     "order",
     "offset",
     "limit",
 ];
 
 pub enum EvaluationResult {
-    Do(Box<dyn Value>),
+    Do,
     SelectedGroups(GitQLObject),
     SelectedInfo,
     SetGlobalVariable,
@@ -48,15 +48,13 @@ pub fn evaluate(
     data_provider: &Box<dyn DataProvider>,
     queries: Vec<Query>,
 ) -> Result<Vec<EvaluationResult>, String> {
-    let mut evaluations_results: Vec<EvaluationResult> = vec![];
+    let mut evaluations_results: Vec<EvaluationResult> = Vec::with_capacity(queries.len());
     for query in queries {
         let evaluation_result = match query {
-            Query::Do(do_statement) => evaluate_do_query(env, &do_statement),
-            Query::Select(gql_query) => evaluate_select_query(env, data_provider, gql_query),
-            Query::GlobalVariableDeclaration(global) => {
-                evaluate_global_declaration_query(env, &global)
-            }
-            Query::Describe(describe_statement) => evaluate_describe_query(env, describe_statement),
+            Query::Do(do_query) => evaluate_do_query(env, &do_query),
+            Query::Select(select_query) => evaluate_select_query(env, data_provider, select_query),
+            Query::GlobalVariableDecl(global) => evaluate_global_declaration_query(env, &global),
+            Query::DescribeTable(describe_query) => evaluate_describe_query(env, describe_query),
             Query::ShowTables => evaluate_show_tables_query(env),
         }?;
         evaluations_results.push(evaluation_result);
@@ -66,29 +64,27 @@ pub fn evaluate(
 
 fn evaluate_do_query(
     env: &mut Environment,
-    do_statement: &DoStatement,
+    do_query: &DoQuery,
 ) -> Result<EvaluationResult, String> {
-    Ok(EvaluationResult::Do(evaluate_expression(
-        env,
-        &do_statement.expression,
-        &[],
-        &vec![],
-    )?))
+    for expr in do_query.exprs.iter() {
+        evaluate_expression(env, expr, &[], &vec![])?;
+    }
+    Ok(EvaluationResult::Do)
 }
 
 #[allow(clippy::borrowed_box)]
 fn evaluate_select_query(
     env: &mut Environment,
     data_provider: &Box<dyn DataProvider>,
-    query: GQLQuery,
+    select_query: SelectQuery,
 ) -> Result<EvaluationResult, String> {
     let mut gitql_object = GitQLObject::default();
-    let mut alias_table: HashMap<String, String> = query.alias_table;
+    let mut alias_table: HashMap<String, String> = select_query.alias_table;
 
-    let hidden_selections_map = query.hidden_selections;
+    let hidden_selections_map = select_query.hidden_selections;
     let hidden_selections: Vec<String> =
         hidden_selections_map.values().flatten().cloned().collect();
-    let mut statements_map = query.statements;
+    let mut statements_map = select_query.statements;
     let has_group_by_statement = statements_map.contains_key("group");
 
     let mut distinct: Option<Distinct> = None;
@@ -162,8 +158,8 @@ fn evaluate_select_query(
     // If it a single group but it select only aggregations function,
     // should return only first element in the group
     else if number_of_groups == 1
-        && !query.has_group_by_statement
-        && query.has_aggregation_function
+        && !select_query.has_group_by_statement
+        && select_query.has_aggregation_function
         && main_group.len() > 1
     {
         main_group.rows.drain(1..);
@@ -189,37 +185,35 @@ fn evaluate_select_query(
 
 fn evaluate_global_declaration_query(
     env: &mut Environment,
-    statement: &GlobalVariableStatement,
+    global_decl_query: &GlobalVariableDeclQuery,
 ) -> Result<EvaluationResult, String> {
-    execute_global_variable_statement(env, statement)?;
+    let value = evaluate_expression(env, &global_decl_query.value, &[], &vec![])?;
+    env.globals
+        .insert(global_decl_query.name.to_string(), value);
     Ok(EvaluationResult::SetGlobalVariable)
 }
 
 fn evaluate_describe_query(
     env: &mut Environment,
-    stmt: DescribeStatement,
+    describe_query: DescribeQuery,
 ) -> Result<EvaluationResult, String> {
     let table_fields = env
         .schema
         .tables_fields_names
-        .get(&stmt.table_name.as_str())
+        .get(&describe_query.table_name.as_str())
         .unwrap();
 
     let mut gitql_object = GitQLObject::default();
-    gitql_object.titles.push("Field".to_owned());
-    gitql_object.titles.push("Type".to_owned());
+    gitql_object.titles.push("field".to_owned());
+    gitql_object.titles.push("type".to_owned());
 
     let mut rows: Vec<Row> = Vec::with_capacity(table_fields.len());
     for field in table_fields {
         let value = env.schema.tables_fields_types.get(field).unwrap();
         rows.push(Row {
             values: vec![
-                Box::new(TextValue {
-                    value: field.to_owned().to_owned(),
-                }),
-                Box::new(TextValue {
-                    value: value.literal(),
-                }),
+                Box::new(TextValue::new(field.to_owned().to_owned())),
+                Box::new(TextValue::new(value.literal())),
             ],
         })
     }
@@ -233,10 +227,8 @@ fn evaluate_show_tables_query(env: &mut Environment) -> Result<EvaluationResult,
 
     let mut rows: Vec<Row> = Vec::with_capacity(tables.len());
     for table in env.schema.tables_fields_names.keys() {
-        let values: Vec<Box<dyn Value>> = vec![Box::new(TextValue {
-            value: table.to_owned().to_owned(),
-        })];
-
+        let values: Vec<Box<dyn Value>> =
+            vec![Box::new(TextValue::new(table.to_owned().to_owned()))];
         rows.push(Row { values });
     }
 
