@@ -5,14 +5,13 @@ use gitql_ast::expression::Expr;
 use gitql_ast::expression::ExprKind;
 use gitql_ast::statement::AggregateValue;
 use gitql_ast::statement::AggregationsStatement;
-use gitql_ast::statement::DoStatement;
-use gitql_ast::statement::GlobalVariableStatement;
 use gitql_ast::statement::GroupByStatement;
 use gitql_ast::statement::HavingStatement;
 use gitql_ast::statement::IntoStatement;
 use gitql_ast::statement::LimitStatement;
 use gitql_ast::statement::OffsetStatement;
 use gitql_ast::statement::OrderByStatement;
+use gitql_ast::statement::QualifyStatement;
 use gitql_ast::statement::SelectStatement;
 use gitql_ast::statement::Statement;
 use gitql_ast::statement::StatementKind::*;
@@ -45,10 +44,6 @@ pub fn execute_statement(
     has_group_by_statement: bool,
 ) -> Result<(), String> {
     match statement.kind() {
-        Do => {
-            let statement = statement.as_any().downcast_ref::<DoStatement>().unwrap();
-            execute_do_statement(env, statement, gitql_object)
-        }
         Select => {
             let statement = statement
                 .as_any()
@@ -75,6 +70,13 @@ pub fn execute_statement(
                 .unwrap();
             execute_having_statement(env, statement, gitql_object)
         }
+        Qualify => {
+            let statement = statement
+                .as_any()
+                .downcast_ref::<QualifyStatement>()
+                .unwrap();
+            execute_qualify_statement(env, statement, gitql_object)
+        }
         Limit => {
             let statement = statement.as_any().downcast_ref::<LimitStatement>().unwrap();
             execute_limit_statement(statement, gitql_object)
@@ -84,7 +86,7 @@ pub fn execute_statement(
                 .as_any()
                 .downcast_ref::<OffsetStatement>()
                 .unwrap();
-            execute_offset_statement(statement, gitql_object)
+            execute_offset_statement(env, statement, gitql_object)
         }
         OrderBy => {
             let statement = statement
@@ -130,26 +132,9 @@ pub fn execute_statement(
             let statement = statement.as_any().downcast_ref::<IntoStatement>().unwrap();
             execute_into_statement(statement, gitql_object)
         }
-        GlobalVariable => {
-            let statement = statement
-                .as_any()
-                .downcast_ref::<GlobalVariableStatement>()
-                .unwrap();
-            execute_global_variable_statement(env, statement)
-        }
     }
 }
 
-fn execute_do_statement(
-    env: &mut Environment,
-    statement: &DoStatement,
-    gitql_object: &mut GitQLObject,
-) -> Result<(), String> {
-    let row_values = &gitql_object.groups[0].rows[0].values;
-    evaluate_expression(env, &statement.expression, &gitql_object.titles, row_values)?;
-    Ok(())
-}
-
 #[allow(clippy::borrowed_box)]
 fn execute_select_statement(
     env: &mut Environment,
@@ -331,6 +316,25 @@ fn execute_having_statement(
     Ok(())
 }
 
+fn execute_qualify_statement(
+    env: &mut Environment,
+    statement: &QualifyStatement,
+    gitql_object: &mut GitQLObject,
+) -> Result<(), String> {
+    if gitql_object.is_empty() {
+        return Ok(());
+    }
+
+    apply_filter_operation(
+        env,
+        &statement.condition,
+        &gitql_object.titles,
+        &mut gitql_object.groups[0].rows,
+    )?;
+
+    Ok(())
+}
+
 fn execute_limit_statement(
     statement: &LimitStatement,
     gitql_object: &mut GitQLObject,
@@ -352,6 +356,7 @@ fn execute_limit_statement(
 }
 
 fn execute_offset_statement(
+    env: &mut Environment,
     statement: &OffsetStatement,
     gitql_object: &mut GitQLObject,
 ) -> Result<(), String> {
@@ -364,9 +369,21 @@ fn execute_offset_statement(
     }
 
     let main_group: &mut Group = &mut gitql_object.groups[0];
-    main_group
-        .rows
-        .drain(0..cmp::min(statement.count, main_group.len()));
+    let start = &evaluate_expression(
+        env,
+        &statement.start,
+        &gitql_object.titles,
+        &main_group.rows[0].values,
+    )?;
+
+    // If start evaluates to NULL, it is treated the same as OFFSET 0
+    if start.is_null() {
+        return Ok(());
+    }
+
+    let offset = start.as_int().unwrap() as usize;
+    let main_group: &mut Group = &mut gitql_object.groups[0];
+    main_group.rows.drain(0..cmp::min(offset, main_group.len()));
 
     Ok(())
 }
@@ -471,15 +488,6 @@ fn execute_aggregation_functions_statement(
     Ok(())
 }
 
-pub fn execute_global_variable_statement(
-    env: &mut Environment,
-    statement: &GlobalVariableStatement,
-) -> Result<(), String> {
-    let value = evaluate_expression(env, &statement.value, &[], &vec![])?;
-    env.globals.insert(statement.name.to_string(), value);
-    Ok(())
-}
-
 #[inline(always)]
 pub fn resolve_actual_column_name(alias_table: &HashMap<String, String>, name: &str) -> String {
     if let Some(column_name) = alias_table.get(name) {
