@@ -1,6 +1,8 @@
 use std::collections::HashMap;
 
 use gitql_ast::statement::AggregateValue;
+use gitql_ast::statement::WindowDefinition;
+use gitql_ast::statement::WindowValue;
 
 use crate::name_generator::NameGenerator;
 use crate::token::SourceLocation;
@@ -9,6 +11,9 @@ use crate::token::SourceLocation;
 pub struct ParserContext {
     pub aggregations: HashMap<String, AggregateValue>,
 
+    pub window_functions: HashMap<String, WindowValue>,
+    pub named_window_clauses: HashMap<String, WindowDefinition>,
+
     pub selected_fields: Vec<String>,
     pub hidden_selections: Vec<String>,
 
@@ -19,7 +24,12 @@ pub struct ParserContext {
     pub name_alias_table: HashMap<String, String>,
     pub name_generator: NameGenerator,
 
-    pub has_select_statement: bool,
     pub is_single_value_query: bool,
+    pub has_select_statement: bool,
     pub has_group_by_statement: bool,
+
+    pub inside_selections: bool,
+    pub inside_having: bool,
+    pub inside_order_by: bool,
+    pub inside_over_clauses: bool,
 }
