@@ -11,5 +11,8 @@ pub(crate) mod parse_cast;
 pub(crate) mod parse_comparisons;
 pub(crate) mod parse_function_call;
 pub(crate) mod parse_interval;
+pub(crate) mod parse_into;
+pub(crate) mod parse_ordering;
+pub(crate) mod parse_string_matchers;
 pub(crate) mod parse_type;
 pub mod parser;
